.siteseo-sidebar-active-tab{border-bottom:1.5px solid #00308f}.siteseo-sidebar-tabs{display:flex;justify-content:center;width:100%}.siteseo-sidebar-tabs>button{width:100%}.preview-block{background-color:#fff;width:100%}.preview-url{color:#202124;font-size:14px;line-height:16px;margin:3px 0 5px;padding:10px 5px 0 0}.preview-title,.preview-url{max-width:600px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;width:100%}.preview-title{color:#1a0dab;font-size:16px;font-weight:400;line-height:1.5;margin-bottom:3px;padding-bottom:0}.preview-description{line-height:1.4;white-space:normal;word-wrap:break-word;color:#555d66;text-overflow:ellipsis}.siteseo-gut-title-fields{margin-top:15px}.siteseo-gut-title-field{margin-bottom:10px}
